==> oura-0.3.7.crate: oura-0.3.7/src/sinks/elastic/setup.rs <==
use std::sync::mpsc::Receiver;

use elasticsearch::{
    auth::Credentials as ESCredentials,
    cert::CertificateValidation,
    http::{
        transport::{SingleNodeConnectionPool, TransportBuilder},
        Url,
    },
    Elasticsearch,
};

use serde_derive::Deserialize;

use crate::framework::{BootstrapResult, Event, SinkConfig};

use super::run::writer_loop;

#[derive(Debug, Deserialize)]
#[serde(tag = "type")]
pub enum CredentialsConfig {
    Basic { username: String, password: String },
}

impl Into<ESCredentials> for &CredentialsConfig {
    fn into(self) -> ESCredentials {
        match self {
            CredentialsConfig::Basic { username, password } => {
                ESCredentials::Basic(username.clone(), password.clone())
            }
        }
    }
}

#[derive(Default, Debug, Deserialize)]
pub struct Config {
    url: String,
    index: String,
    credentials: Option<CredentialsConfig>,
}

impl SinkConfig for Config {
    fn bootstrap(&self, input: Receiver<Event>) -> BootstrapResult {
        let pool = SingleNodeConnectionPool::new(Url::parse(&self.url)?);
        let mut transport =
            TransportBuilder::new(pool).cert_validation(CertificateValidation::None);

        if let Some(creds) = &self.credentials {
            transport = transport.auth(creds.into());
        };

        let client = Elasticsearch::new(transport.build()?);

        let index = self.index.clone();
        let handle = std::thread::spawn(move || {
            writer_loop(input, client, index).expect("writer loop failed")
        });

        Ok(handle)
    }
}

==> oura-0.3.8.crate: oura-0.3.8/src/sinks/elastic/setup.rs <==
use std::sync::mpsc::Receiver;

use elasticsearch::{
    auth::Credentials as ESCredentials,
    cert::CertificateValidation,
    http::{
        transport::{SingleNodeConnectionPool, TransportBuilder},
        Url,
    },
    Elasticsearch,
};

use serde_derive::Deserialize;

use crate::framework::{BootstrapResult, Event, SinkConfig};

use super::run::writer_loop;

#[derive(Debug, Deserialize)]
#[serde(tag = "type")]
pub enum CredentialsConfig {
    Basic { username: String, password: String },
}

impl From<&CredentialsConfig> for ESCredentials {
    fn from(other: &CredentialsConfig) -> Self {
        match other {
            CredentialsConfig::Basic { username, password } => {
                ESCredentials::Basic(username.clone(), password.clone())
            }
        }
    }
}

#[derive(Default, Debug, Deserialize)]
pub struct Config {
    url: String,
    index: String,
    credentials: Option<CredentialsConfig>,

    #[serde(default)]
    idempotency: bool,
}

impl SinkConfig for Config {
    fn bootstrap(&self, input: Receiver<Event>) -> BootstrapResult {
        let pool = SingleNodeConnectionPool::new(Url::parse(&self.url)?);
        let mut transport =
            TransportBuilder::new(pool).cert_validation(CertificateValidation::None);

        if let Some(creds) = &self.credentials {
            transport = transport.auth(creds.into());
        };

        let client = Elasticsearch::new(transport.build()?);

        let index = self.index.clone();
        let idempotency = self.idempotency;
        let handle = std::thread::spawn(move || {
            writer_loop(input, client, index, idempotency).expect("writer loop failed")
        });

        Ok(handle)
    }
}
